@@ -4,6 +4,8 @@
 """ Helper functions to reduce code reuse and misc other uses
 """
 
+from time import time
+
 try:
     from urllib.parse import quote
 except ImportError:
@@ -48,8 +50,16 @@ def escape_url_string(string):
 
 def generate_querystring(dictionary):
     """ Generates a querystring from a dictionary
+
+    Removes all `None` values
     """
 
-    querystring = "".join({"&{0}={1}".format(k, v) for k, v in dictionary.items()})
+    dict_no_none = {k: v for k, v in dictionary.items() if v}
+
+    querystring = "".join({"&{0}={1}".format(k, v) for k, v in dict_no_none.items()})
 
     return querystring.replace("&", "?", 1)
+
+
+def create_timestamp(duration):
+    return int(time() * 1000) + (duration * 1000)
