@@ -46,6 +46,7 @@ def agent_check(
         token,
         customerid=None,
         label="",
+        autodiag=False,
         interval=1,
         enabled=DEFAULTS['enabled'],
         public=DEFAULTS['public'],
@@ -71,6 +72,8 @@ def agent_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type interval: int
     :param interval: Interval in minutes to monitor target
     :type enabled: bool
@@ -103,6 +106,7 @@ def audio_check(
         target,
         customerid=None,
         label="",
+        autodiag=False,
         verifyvolume=False,
         volumemin=-45,
         interval=DEFAULTS['interval'],
@@ -130,6 +134,8 @@ def audio_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :param verifyvolume: enable/disable volume detection
     :type verifyvolume: bool
     :param volumemin: The acceptable range for volume detection
@@ -168,6 +174,7 @@ def cluster_check(
         data,
         customerid="",
         label="",
+        autodiag=False,
         interval=DEFAULTS['interval'],
         enabled=DEFAULTS['enabled'],
         public=DEFAULTS['public'],
@@ -202,6 +209,8 @@ def cluster_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type interval: int
     :param interval: Interval in minutes to monitor target
     :type enabled: bool
@@ -242,9 +251,11 @@ def dns_check(
         transport='udp',
         dnstype='A',
         dnsrd=1,
+        dnssection="answer",
         contentstring="",
         dnstoresolve="",
         label="",
+        autodiag=False,
         interval=DEFAULTS['interval'],
         enabled=DEFAULTS['enabled'],
         public=DEFAULTS['public'],
@@ -279,6 +290,8 @@ def dns_check(
     :param dnstoresolve: FQDN/IP you want to resolve
     :type label: string
     :param label: Name of check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type interval: int
     :param interval: Interval in minutes to monitor target
     :type enabled: bool
@@ -311,11 +324,104 @@ def dns_check(
     return _query_nodeping_api.post(url, check_variables)
 
 
+def doh_dot_check(
+        token,
+        target,
+        dnstoresolve,
+        label="",
+        autodiag=False,
+        customerid="",
+        dohdot="doh",
+        method="GET",
+        statuscode="200",
+        sendheaders={},
+        clientcert="",
+        verify=False,
+        dnstype="A",
+        contentstring="",
+        edns={},
+        ipv6=False,
+        interval=DEFAULTS['interval'],
+        enabled=DEFAULTS['enabled'],
+        public=DEFAULTS['public'],
+        runlocations=DEFAULTS['runlocations'],
+        homeloc=DEFAULTS['homeloc'],
+        threshold=DEFAULTS['threshold'],
+        sens=DEFAULTS['sens'],
+        dep="",
+        notifications="",
+        **kwargs
+):
+    """ Creates a NodePing DNS check
+
+    :type token: str
+    :param token: NodePing account API token
+    :type target: str
+    :param target: URL of host to monitor
+    :type dnstoresolve: str
+    :param dnstoresolve: FQDN to query on target
+    :type label: str
+    :param label: name for the check
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
+    :type customerid: string
+    :param customerid: Optional NodePing subaccount ID
+    :type dohdot: str
+    :param dohdot: Select DoH or DoT
+    :type method: str
+    :param method: Select GET or POST
+    :type statuscode: str
+    :param statuscode: Expected Response HTTP status code (DoH only)
+    :type sendheaders: dict
+    :param sendheaders: Request Headers (DoH only)
+    :type clientcert: str
+    :param clientcert: string to specify the ID of a client cert/key to be used
+    :type verify: bool
+    :param verify: Whether or not to verify the SSL cert
+    :type dnstype: str
+    :param dnstype: Type of DNS record to query
+    :type contentstring: str
+    :param contentstring: What you expect the response to be when resolved
+    :type edns: dict
+    :param edns: optional object used to send EDNS(0) OPT pseuedo-records in a DNS query
+    :type ipv6: bool
+    :param ipv6: Whether to resolve IPv4 or IPv6
+    :type interval: int
+    :param interval: Interval in minutes to monitor target
+    :type enabled: bool
+    :param enabled: If created check will be enabled or disabled
+    :type public: bool
+    :param public: If the results for the created check will be public or not
+    :type runlocations: str
+    :param runlocations: Which region to be originated from
+    :type homeloc: str
+    :param homeloc: Which probe in the region to originate the check from
+    :type threshold: int
+    :param threshold: Time in seconds for an acceptable response
+    :type sens: int
+    :param sens: Rechecks to help avoid unecessary notifications
+    :type dep: string
+    :param dep: ID of the check used for the notification dependency
+    :type notifications: list
+    :param notifications: list of objects containing contact ID, delay, and
+    scheduling for notifications
+    :return: Response from NodePing
+    :rtype: dict
+    """
+
+    check_variables = _package_variables(locals(), 'DOHDOT')
+
+    url = _utils.create_url(token, API_URL, customerid)
+
+    return _query_nodeping_api.post(url, check_variables)
+
+
 def ftp_check(
         token,
         target,
         customerid="",
         label="",
+        autodiag=False,
         port=21,
         username="",
         password="",
@@ -342,6 +448,8 @@ def ftp_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type port: int
     :param port: Port to FTP server
     :type username: string
@@ -387,6 +495,7 @@ def http_check(
         target,
         customerid="",
         label="",
+        autodiag=False,
         ipv6=False,
         follow=False,
         interval=DEFAULTS['interval'],
@@ -410,6 +519,8 @@ def http_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type ipv6: bool
     :param ipv6: Whether to resolve IPv4 or IPv6
     :type follow: bool
@@ -449,6 +560,7 @@ def httpadv_check(
         target,
         customerid="",
         label="",
+        autodiag=False,
         invert=False,
         contentstring="",
         data="",
@@ -488,6 +600,8 @@ def httpadv_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type invert: bool
     :param invert: Used for "Does not contain" functionality
     :type data: dict
@@ -541,6 +655,7 @@ def httpcontent_check(
         target,
         customerid="",
         label="",
+        autodiag=False,
         invert=False,
         contentstring="",
         ipv6=False,
@@ -568,6 +683,8 @@ def httpcontent_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type invert: bool
     :param invert: Used for "Does not contain" functionality
     :type contentstring: string
@@ -611,7 +728,9 @@ def httpparse_check(
         target,
         customerid="",
         label="",
+        autodiag=False,
         fields="",
+        sendheaders={},
         interval=DEFAULTS['interval'],
         enabled=DEFAULTS['enabled'],
         public=DEFAULTS['public'],
@@ -630,20 +749,23 @@ def httpparse_check(
     Each object should have a name, min, and max
 
     Example dictionary:
-        fields = {
+    fields = {
         "fields": {
-        "processmem": {
-        "name": "processmem",
-        "min": 1000,
-        "max": 5000
-        },
-        "cpuload": {
-        "name": "cpuload",
-        "min": 1,
-        "max": 5
-        }
-        }
+            "processmem": {
+                "name": "processmem",
+                "min": 1000,
+                "max": 5000
+            },
+            "cpuload": {
+                "name": "cpuload",
+                "min": 1,
+                "max": 5
+            }
         }
+    }
+
+    Example sendheaders:
+    sendheaders = {"Content-Type": "application/json"}
 
     :type token: string
     :param token: NodePing account API token
@@ -653,9 +775,13 @@ def httpparse_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type fields: dict
     :param fields: Keyed list of fields, with an arbitrary string as the key.
     Should contain 3 elements: name, min, and max
+    :type sendheaders: dict
+    :param sendheaders: HTTP Headers to send in request
     :type interval: int
     :param interval: Interval in minutes to monitor target
     :type enabled: bool
@@ -693,6 +819,7 @@ def imap4_check(
         target,
         customerid="",
         label="",
+        autodiag=False,
         port=143,
         verify=True,
         email="",
@@ -721,6 +848,8 @@ def imap4_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type port: int
     :param port: The port used to test IMAP4 communications
     :type verify: bool
@@ -770,6 +899,7 @@ def mysql_check(
         target,
         customerid=None,
         label="",
+        autodiag=False,
         interval=DEFAULTS['interval'],
         enabled=DEFAULTS['enabled'],
         public=DEFAULTS['public'],
@@ -791,6 +921,8 @@ def mysql_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type interval: int
     :param interval: Interval in minutes to monitor target
     :type enabled: bool
@@ -826,6 +958,7 @@ def ntp_check(
         target,
         customerid=None,
         label="",
+        autodiag=False,
         invert=False,
         port=123,
         interval=DEFAULTS['interval'],
@@ -853,6 +986,8 @@ def ntp_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type invert: bool
     :param invert: True means the check will pass if there is a response
     :type port: int
@@ -892,6 +1027,7 @@ def ping_check(
         target,
         customerid=None,
         label="",
+        autodiag=False,
         ipv6=DEFAULTS['ipv6'],
         interval=DEFAULTS['interval'],
         enabled=DEFAULTS['enabled'],
@@ -918,6 +1054,8 @@ def ping_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type ipv6: bool
     :param ipv6: If the ping should be icmpv6
     :type interval: int
@@ -955,6 +1093,7 @@ def pop3_check(
         target,
         customerid=None,
         label="",
+        autodiag=False,
         port="",
         verify=True,
         email="",
@@ -987,6 +1126,8 @@ def pop3_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type port: int
     :param port: The port used to test POP communications
     :type verify: bool
@@ -1036,6 +1177,7 @@ def port_check(
         target,
         customerid=None,
         label="",
+        autodiag=False,
         invert=False,
         port="",
         interval=DEFAULTS['interval'],
@@ -1058,6 +1200,8 @@ def port_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type invert: bool
     :param invert: False if you expect to not have connections to port accepted
     :type port: int
@@ -1097,6 +1241,7 @@ def push_check(
         checktoken="reset",
         customerid=None,
         label="",
+        autodiag=False,
         fields="",
         interval=DEFAULTS['interval'],
         enabled=DEFAULTS['enabled'],
@@ -1145,6 +1290,8 @@ def push_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type fields: dict
     :param fields: Contents of each metric collected with min/max values
     :type interval: int
@@ -1184,6 +1331,7 @@ def rbl_check(
         target,
         customerid=None,
         label="",
+        autodiag=False,
         ignore="",
         interval=DEFAULTS['interval'],
         enabled=DEFAULTS['enabled'],
@@ -1211,6 +1359,8 @@ def rbl_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type ignore: list
     :param ignore: A list of DNSBL blacklists to ignore
     :type interval: int
@@ -1248,6 +1398,7 @@ def rdp_check(
         target,
         customerid=None,
         label="",
+        autodiag=False,
         interval=DEFAULTS['interval'],
         enabled=DEFAULTS['enabled'],
         public=DEFAULTS['public'],
@@ -1269,6 +1420,8 @@ def rdp_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type interval: int
     :param interval: Interval in minutes to monitor target
     :type enabled: bool
@@ -1304,6 +1457,7 @@ def spec10dns_check(
         data,
         customerid="",
         label="",
+        autodiag=False,
         interval=DEFAULTS['interval'],
         enabled=DEFAULTS['enabled'],
         public=DEFAULTS['public'],
@@ -1338,6 +1492,8 @@ def spec10dns_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type interval: int
     :param interval: Interval in minutes to monitor target
     :type enabled: bool
@@ -1375,6 +1531,7 @@ def spec10rdds_check(
         data,
         customerid="",
         label="",
+        autodiag=False,
         interval=DEFAULTS['interval'],
         enabled=DEFAULTS['enabled'],
         public=DEFAULTS['public'],
@@ -1409,6 +1566,10 @@ def spec10rdds_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of check that will be created
+    :type transport: bool/string
+    :param transport: whether the check should be both TCP/UDP (False), "udp", or "tcp"
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type interval: int
     :param interval: Interval in minutes to monitor target
     :type enabled: bool
@@ -1446,6 +1607,8 @@ def sip_check(
         target,
         customerid=None,
         label="",
+        transport=False,
+        autodiag=False,
         interval=DEFAULTS['interval'],
         enabled=DEFAULTS['enabled'],
         public=DEFAULTS['public'],
@@ -1467,6 +1630,8 @@ def sip_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type interval: int
     :param interval: Interval in minutes to monitor target
     :type enabled: bool
@@ -1502,6 +1667,7 @@ def smtp_check(
         target,
         customerid=None,
         label="",
+        autodiag=False,
         invert=False,
         port=25,
         verify=True,
@@ -1530,6 +1696,8 @@ def smtp_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type invert: bool
     :param invert: Check whether or not SMTP accepts mail from the address
     :type port: int
@@ -1581,6 +1749,7 @@ def snmp_check(
         target,
         customerid=None,
         label="",
+        autodiag=False,
         port=161,
         fields="",
         snmpv=1,
@@ -1626,6 +1795,8 @@ def snmp_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type port: int
     :param port: Port for testing SNMP connectivity
     :type fields: dict
@@ -1671,6 +1842,7 @@ def ssh_check(
         target,
         customerid=None,
         label="",
+        autodiag=False,
         invert=False,
         contentstring="",
         port=22,
@@ -1697,6 +1869,8 @@ def ssh_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type contentstring: string
     :param contentstring: string to look for in the response after login
     :type port: int
@@ -1740,7 +1914,9 @@ def ssl_check(
         target,
         customerid=None,
         label="",
+        autodiag=False,
         warningdays="",
+        servername="",
         interval=DEFAULTS['interval'],
         enabled=DEFAULTS['enabled'],
         public=DEFAULTS['public'],
@@ -1762,8 +1938,12 @@ def ssl_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type warningdays: int
     :param warningdays: Number of days to warn about expiring SSL/TLS cert
+    :type servername: string
+    :param servername: specifies the FQDN sent to SNI services in the SSL check
     :type interval: int
     :param interval: Interval in minutes to monitor target
     :type enabled: bool
@@ -1799,6 +1979,7 @@ def websocket_check(
         target,
         customerid=None,
         label="",
+        autodiag=False,
         invert=False,
         contentstring="",
         data="",
@@ -1823,6 +2004,8 @@ def websocket_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type invert: bool
     :param invert: If the response does/does not contain a string
     :type contentstring: string
@@ -1864,6 +2047,7 @@ def whois_check(
         target,
         customerid=None,
         label="",
+        autodiag=False,
         whoisserver="",
         ipv6=False,
         invert=False,
@@ -1890,6 +2074,8 @@ def whois_check(
     :param customerid: Optional NodePing subaccount ID
     :type label: string
     :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
     :type whoisserver: string
     :param whoisserver: Server to query for whois entry
     :type ipv6: bool
